==> formatusb_22.06.01.tar.xz: formatusb-22.04/translations/formatusb_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <location filename="ui_mainwindow.h" line="285"/>
        <source>Program_Name</source>
        <translation>Program_Name</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="50"/>
        <location filename="ui_mainwindow.h" line="287"/>
        <source>Quit application</source>
        <translation>Surt de l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="53"/>
        <location filename="ui_mainwindow.h" line="289"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="60"/>
        <location filename="ui_mainwindow.h" line="291"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="76"/>
        <location filename="ui_mainwindow.h" line="294"/>
        <source>Display help </source>
        <translation>Mostra l&apos;ajuda</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="79"/>
        <location filename="ui_mainwindow.h" line="296"/>
        <source>Help</source>
        <translation>Ajuda </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="86"/>
        <location filename="ui_mainwindow.h" line="298"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="102"/>
        <location filename="ui_mainwindow.h" line="300"/>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="160"/>
        <location filename="ui_mainwindow.h" line="302"/>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="186"/>
        <location filename="ui_mainwindow.h" line="307"/>
        <source>About this application</source>
        <translation>Quant a aquest programa</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="189"/>
        <location filename="ui_mainwindow.h" line="309"/>
        <source>About...</source>
        <translation>Quant a...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="196"/>
        <location filename="ui_mainwindow.h" line="311"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="237"/>
        <location filename="ui_mainwindow.h" line="321"/>
        <source>USB-DATA</source>
        <translation>USB-DATA</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="244"/>
        <location filename="ui_mainwindow.h" line="313"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Trieu el dispositiu USB&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="267"/>
        <location filename="ui_mainwindow.h" line="319"/>
        <source>Format</source>
        <translation>Format </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="274"/>
        <location filename="ui_mainwindow.h" line="320"/>
        <source>Refresh drive list</source>
        <translation>Refresca la llista d&apos;unitats</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="288"/>
        <location filename="ui_mainwindow.h" line="322"/>
        <source>File System Label</source>
        <translation>Etiqueta del Sistema de Fitxers</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="318"/>
        <location filename="ui_mainwindow.h" line="314"/>
        <source>fat32</source>
        <translation>FAT32</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="323"/>
        <location filename="ui_mainwindow.h" line="315"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="328"/>
        <location filename="ui_mainwindow.h" line="316"/>
        <source>exfat</source>
        <translation>EXFAT</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="333"/>
        <location filename="ui_mainwindow.h" line="317"/>
        <source>ntfs</source>
        <translation>NTFS</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="354"/>
        <source>Show partitions</source>
        <translation>Mostra les particions </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="361"/>
        <source>Show all devices</source>
        <translation>Mostra tots els dispositius </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="181"/>
        <source>Success</source>
        <translation>Èxit</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="181"/>
        <source>Format successful!</source>
        <translation>Formatat correctament!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="183"/>
        <source>Failure</source>
        <translation>Fallada</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="183"/>
        <source>Error encountered in the Format process</source>
        <translation>S&apos;ha trobat un error en el procés de Formatatge</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="236"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="236"/>
        <source>Please select a USB device to write to</source>
        <translation>Si us plau, trieu un altre dispositiu USB per escriure-hi</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="242"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Aquestes accions destruiran totes les dades a
</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="242"/>
        <source>Do you wish to continue?</source>
        <translation>Voleu continuar?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="282"/>
        <source>About %1</source>
        <translation>Quant a %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="283"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="284"/>
        <source>Program for formatting USB devices</source>
        <translation>Programa per formatar dispositius USB</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="286"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="287"/>
        <source>%1 License</source>
        <translation>Llicència de %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="295"/>
        <source>%1 Help</source>
        <translation>Ajuda de %1</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="about.cpp" line="38"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="about.cpp" line="39"/>
        <location filename="about.cpp" line="49"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="about.cpp" line="40"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="about.cpp" line="57"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
</context>
</TS>

==> formatusb_23.12.18.tar.xz: formatusb-23.12.18/translations/formatusb_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Name</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Show all devices</source>
        <translation>Mostra tots els dispositius </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Format</source>
        <translation>Format </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="54"/>
        <source>Defaults</source>
        <translation>Per Omissió</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>msdos</source>
        <translation>MS-DOS</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>gpt</source>
        <translation>GPT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Trieu el dispositiu USB&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="82"/>
        <source>Show partitions</source>
        <translation>Mostra les particions </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="138"/>
        <source>Refresh drive list</source>
        <translation>Refresca la llista d&apos;unitats</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="152"/>
        <source>USB-DATA</source>
        <translation>USB-DATA</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="159"/>
        <source>File System Label</source>
        <translation>Etiqueta del Sistema de Fitxers</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="166"/>
        <source>Partition Table Type</source>
        <translation>Tipus de Taula de Particions</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="225"/>
        <source>Quit application</source>
        <translation>Surt de l&apos;aplicació</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="228"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>Display help </source>
        <translation>Mostra l&apos;ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Help</source>
        <translation>Ajuda </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>About this application</source>
        <translation>Quant a aquest programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="318"/>
        <source>About...</source>
        <translation>Quant a...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="357"/>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="383"/>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <source>Success</source>
        <translation>Èxit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <source>Format successful!</source>
        <translation>Formatat correctament!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="186"/>
        <location filename="../mainwindow.cpp" line="315"/>
        <source>Failure</source>
        <translation>Fallada</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="186"/>
        <source>Error encountered in the Format process</source>
        <translation>S&apos;ha trobat un error en el procés de Formatatge</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="217"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="217"/>
        <source>Please select a USB device to write to</source>
        <translation>Si us plau, trieu un altre dispositiu USB per escriure-hi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Aquestes accions destruiran totes les dades a
</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <source>Do you wish to continue?</source>
        <translation>Voleu continuar?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>About %1</source>
        <translation>Quant a %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="259"/>
        <source>Version: </source>
        <translation>Versió: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <source>Program for formatting USB devices</source>
        <translation>Programa per formatar dispositius USB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>%1 License</source>
        <translation>Llicència de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>%1 Help</source>
        <translation>Ajuda de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="315"/>
        <source>Invalid Name</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>License</source>
        <translation>Llicència</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="35"/>
        <location filename="../about.cpp" line="45"/>
        <source>Changelog</source>
        <translation>Registre de canvis</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="36"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <source>&amp;Close</source>
        <translation>Tan&amp;ca </translation>
    </message>
</context>
</TS>
